import Footer from '@/components/Footer';
import { login } from '@/services/api/user';
import { LockOutlined, UserOutlined } from '@ant-design/icons';
import { LoginForm, ProFormText } from '@ant-design/pro-components';
import { history, useModel } from '@umijs/max';
import { Alert, message, Form, Button, Input } from 'antd';
import { useState } from 'react';
import md5 from 'md5';
import Logo from '@/assets/images/logo.png';
import decorateLeft from '@/assets/images/login/装饰左.png';
import decorateRight from '@/assets/images/login/装饰右.png';
import './index.less';

const errStyle = {color: 'red', paddingBottom: '10px'}

const Login = () => {
  const [type, setType] = useState('account');
  const { initialState, setInitialState } = useModel('@@initialState');
  const [errMsg, setErrMsg] = useState()

  const handleSubmit = async (values) => {
    try {
      // 登录
      const res = await login({ ...values, password: md5(values.password) });
      console.log(res);

      const defaultLoginSuccessMessage = '登录成功！';
      message.success(defaultLoginSuccessMessage);
      
      setInitialState({
        currentUser: res.user,
      });
      
      const urlParams = new URL(window.location.href).searchParams;
      history.push(urlParams.get('redirect') || '/');
      return;

      
    } catch (error) {
      console.log(error);
    }
  };

  return (
    <div className="page-container">
      <Form name="login" id="login" onFinish={handleSubmit}>
        <div className="form-left">
          <img src={Logo} />
        </div>
        <div className="form-right">
          <h2>用户登录</h2>
          <div className="sub-title">
            <img src={decorateLeft} alt="" />
            <span>Welcome</span>
            <img src={decorateRight} alt="" />
          </div>
          <div id="msg" style={errStyle}>{errMsg}</div>
          <Form.Item className="input-control" name="userName" required>
            <Input type="text" prefix={<UserOutlined />} className="form-control cust-input" placeholder="用户名" />
          </Form.Item>
          <Form.Item className="input-control" name="password" required>
            <Input type="password" prefix={<LockOutlined />} className="form-control cust-input" placeholder="密码" />
          </Form.Item>
          <Form.Item className="form-group" style={{ marginBottom: '60px' }}>
            <Button type="primary" className="btn-primary" htmlType="submit">登 录</Button>
          </Form.Item>
        </div>
      </Form>
    </div>
  );
};

export default Login;
