import { message } from 'antd';

function requestInterceptor(url, options) {
  const headers = options.headers || {};
  const token = sessionStorage.getItem('token') || '';

  return {
    // url,
    url: `${API_BASE}/api${url}`,
    options: {
      ...options,
      headers: {
        ...headers,
        Authorization: token,
      },
    },
  };
}

async function responseInterceptor(response) {
  if (response.headers['content-type'] === 'application/vnd.ms-excel;charset=utf-8') {
    return response;
  }

  const { data } = response;
  if (data.code === 1000) {
    if (data.data.token) {
      sessionStorage.setItem('token', data.data.token);
    }

    return data;
  } else {
    if (response.config.showType !== 0) {
      const errMsg = data.message || '系统错误';
      message.error(errMsg.indexOf('exception') > -1 ? '服务异常' : errMsg);
    }
  }

  console.error(response);

  return Promise.reject(data.message || '系统错误');
}

export const requestConfig = {
  requestInterceptors: [requestInterceptor],
  responseInterceptors: [responseInterceptor],
};

export function queryTable(apiRequest) {
  return function (params) {
    const { current, pageSize, ...leftParams } = params;
    return apiRequest({
      pageSize,
      pageNum: params.current,
      ...(leftParams || {}),
    })
      .then((res) => {
        return {
          data: res.records,
          success: true,
          total: res.total,
        };
      })
      .catch((err) => {
        return {
          success: false,
        };
      });
  };
}

export function queryDict(apiRequest) {
  return function (params, labelKey = 'name', valueKey = 'id') {
    const { current, pageSize, ...leftParams } = params || {};
    return apiRequest({
      pageSize: 9999,
      pageNum: 1,
      ...(leftParams || {}),
    })
      .then((res) => {
        return res?.records?.map((x) => ({
          label: x[labelKey],
          value: x[valueKey],
          ...x,
        }));
      })
      .catch((err) => {
        return {
          success: false,
        };
      });
  };
}
